@@ -470,6 +470,9 @@ class DobissAPI:
             url = f"http://{host}/api/local/"
             ws_url = f"ws://{host}/sockets/api"
 
+        logger.debug(
+            f"Init DobissAPI object to {host} using secret starting with {secret[0:6]} (secure = {secure})"
+        )
         self._host = host
         self._secure = secure
         self._token = ""
@@ -522,6 +525,9 @@ class DobissAPI:
     async def auth_check(self):
         headers = {"Authorization": "Bearer " + self.get_token()}
         auth_ok = False
+        logger.debug(
+            f"Authenticating DobissAPI {self._host} using secret starting with {self._secret[0:6]} (secure = {self._secure})"
+        )
         try:
             self.start_session()
             async with self._session.get(
@@ -762,9 +768,16 @@ class DobissAPI:
                             or str(subject["icons_id"]) == str(DOBISS_VENTILATION)
                             or str(subject["icons_id"]) == str(DOBISS_HEATING)
                         ):
-                            new_devices.append(
-                                DobissSwitch(self, subject, group["group"]["name"])
-                            )
+                            if subject["dimmable"] is not None:
+                                new_devices.append(
+                                    DobissAnalogOutput(
+                                        self, subject, group["group"]["name"]
+                                    )
+                                )
+                            else:
+                                new_devices.append(
+                                    DobissSwitch(self, subject, group["group"]["name"])
+                                )
         for dev in new_devices:
             existing_dev = self.get_device_by_id(dev.object_id)
             if existing_dev:
@@ -884,6 +897,7 @@ class DobissAPI:
                     f"Failed to connect, waiting a bit before retrying: {repr(error)}"
                 )
                 await asyncio.sleep(10)
+            logger.debug("Restarting dobiss websocket connection")
 
     def stop_monitoring(self):
         self._stop_monitoring = True
